Lists - Tabler - Premium and Open Source dashboard template with responsive and high quality UI.

## Lists

### Top users

Paweł Kuna
2 days ago
JL
Jeffie Lewzey
3 days ago
Mallory Hulme
today
Dunn Slane
6 days ago
Emmy Levet
3 days ago
Maryjo Lebarree
2 days ago
EP
Egan Poetz
4 days ago
Kellie Skingley
6 days ago
Christabel Charlwood
today
HS
Haskel Shelper
yesterday

### Contacts

Christabel Charlwood
Compressed Sass output support (#29702)
HS
Haskel Shelper
Set vertical-align on .form-check-input (#29521)
Lorry Mion
Keep themed appearance for print (#29714)
Leesa Beaty
Use double quotes in `.stylelintrc` (#29709)
Perren Keemar
Regenerate package-lock.json (#29695)
SA
Sunny Airey
Switch to the Coveralls Action (#29478)
Geoffry Flaunders
Fix npm audit vulnerability (#29677)
Thatcher Keel
config.yml: update popper.js to v1.16.0 (#29624)

### Links and buttons

The current link item A second link item A third link item A fourth link item A disabled link item

### Last commits

Paweł Kuna
Change deprecated html tags to text decoration classes (#29604)
JL
Jeffie Lewzey
justify-content:between ⇒ justify-content:space-between (#29734)
Mallory Hulme
Update change-version.js (#29736)
Dunn Slane
Regenerate package-lock.json (#29730)
Emmy Levet
Some minor text tweaks
Maryjo Lebarree
Link to versioned docs
EP
Egan Poetz
Copywriting edits
Kellie Skingley
Enable RFS for font resizing

### People

A
Eva Acres
Change deprecated html tags to text decoration classes (#29604)
SA
Sunny Airey
justify-content:between ⇒ justify-content:space-between (#29734)
Northrop Alforde
Update change-version.js (#29736)
Virgil Archbutt
Regenerate package-lock.json (#29730)
Guthry Arlott
Some minor text tweaks
AA
Arlie Armstead
Link to versioned docs
Ashton Arndell
Copywriting edits
Kass Aspinal
Enable RFS for font resizing
Rabi Attle
Compressed Sass output support (#29702)
B
Cary Baleine
Set vertical-align on .form-check-input (#29521)
Borden Barkworth
Keep themed appearance for print (#29714)
Regan Baser
Use double quotes in `.stylelintrc` (#29709)
Leesa Beaty
Regenerate package-lock.json (#29695)
Guendolen Belliss
Switch to the Coveralls Action (#29478)
TB
Tallie Bettis
Fix npm audit vulnerability (#29677)
Donnie Biggin
config.yml: update popper.js to v1.16.0 (#29624)
Mel Bilovus
Update anchor.js to v4.2.1 (#29662)
EB
Errol Blackley
Dist (#29638)
Jermaine Booley
Make check label cursor customizable (#29654)
Cleavland Bratchell
Fixed input-height-sm and input-height-lg calculations (#29653)
Luca Brayn
package.json: Add funding property (#29646)
Tonye Brikner
Remove shx. (#29636)
Granger Brockton
dashboard/index.html: update tabler-icons to v4.24.1 (#29651)
Arin Broxup
Regenerate package-lock.json.
Gwennie Bryce
site/assets/js/search.js: ignore the LGTM alert (#29634)
Kerwinn Burkart
Tighten regex a bit. If we need to make this more robust in the future, we can revert this as needed.
Tamqrah Busher
example.html: use double quotes
C
Delaney Cairney
Example shortcode: use a regex and simplify logic.
Rooney Cassy
Move docs JS one folder up. (#29632)
Howard Catteroll
progress: Fix IE overflow (#29629)
Christabel Charlwood
removing last occurences of _fixTitle in our docs (#29631)
Portie Christou
Update modal.md (#29621) Fix typo
Trefor Cocksedge
Update stylelint-config-twbs-bootstrap to 0.9.0 (#29612)
Mata Codlin
Remove calc function from docs
Julietta Coke
Add calc() to function blacklist
Tonia Colqueran
Doc tweaks.
Tessie Curzon
Revert complex calculation
D
Creighton Deluze
Add add and subtract function
Otha Denial
Update normalizeDataKey to match the spec (#29609)
Verne Diment
Remove redundant "Navbar divider" from "Contents" (#29601)
Stafani Ding
Update .form-check to properly support gradients when enabled (#29338)
Georgeanna Do Rosario
v5: Simplify navbars by requiring containers (#29339)
Ninon Don
Remove unneeded ESLint suppression and regenerate lock file (#29593)
Emmott Dowsett
remove superflous transition parameter (#29595)
E
Carroll Erat
Added animation when modal backdrop is static (#29516)
Peria Errichiello
Add configurable button text wrapping (#29554)
Dyann Escala
Enable eslint no-console rule except for build directory (#29585)
Chalmers Ewington
Regenerate package-lock.json (#29571)
F
Jarred Farthin
Fix one dev npm vulnerability. (#29568)
Geoffry Flaunders
Update hugo-bin to v0.47.0 (Hugo 0.59.0) (#29562)
G
Merrily Garforth
Rename close icon to close button (#29387)
Johnnie Gilby
Get rid of unneeded `div`s. (#29563)
Byrom Gillson
Update popper.js to v1.16.0. (#29537)
Gratia Gooley
v5: Icons docs cleanup (#29450)
Leigha Gorce
v5: Update colors to add shades and tints (#29348)
Jennilee Graves
Add link to Icons site in our docs (#29544)
Lianne Greenroa
Skip hidden dropdowns while focusing (#29523)
Barbara Grenkov
Add make-col-auto mixin (#29367)
Fifi Gumm
Update dependabot config (#29536)
H
Neale Havock
Add dependabot config (#29526)
Haze Hubbert
Update devDependencies. (#29508)
Mallory Hulme
Fix top level ampersand (#29518)
Karlis Hundell
Carousel variables (#29493)
I
Timotheus Iacomo
Group line-height variables (#29466)
Sean Ilyasov
Add color argument to button mixins (#29444)
Reynold Indgs
Add new .bg-body utility class (#29511)
Hillard Ivic
Drop support for Node.js 8. (#29496)
J
Sam Jarlmann
Rename "js/tests/units" to "js/tests/unit". (#29503)
K
Thatcher Keel
Dist (#29484)
Perren Keemar
CI: move `CI` env variable to the root of the workflow. (#29499)
Bernarr Kellett
Update devDependencies. (#29447)
Maddy Kenneway
Add variable for `$breadcrumb-font-size` (#29467)
Sandi Keys
add modularity integration test
Arlan Kilrow
return to the original file structure to avoid breaking modularity
Paweł Kuna
Fix border for single card in accordion (#29453)
L
Marsha Labat
Variable card height (#29462)
Beatrix Ladewig
Better radio input (#29441)
Zitella Lawes
Trim trailing whitespace from markdown files (#29460)
Maryjo Lebarree
Remove appearance from textarea (#29455)
Price Letixier
v5: .form-check layout changes (#29322)
Emmy Levet
Remove "extra" section from composer.json (#29420)
JL
Jeffie Lewzey
coveralls: Add `COVERALLS_GIT_BRANCH` (#29458)
Leandra Liddicoat
workflows/test.yml: specify `CI=true` (#29440)
Rivy Lochet
README.md: link to the Actions page for Tests (#29480)
M
Claudelle MacKilroe
Variable carousel indicator opacity (#29468)
Bettina Matuszyk
Remove outline from select box in FF (#29445)
Odelinda McCosh
Remove duplicated td selector (#29454)
Harriot McGeady
Change blue and pink colors to be accessible. (#29198)
Netti McGreay
Sass: remove redundant stylelint inline suppressions. (#29427)
Shana Meryett
`update-deps`: remove moot `cross-env` call. (#29419)
Marchelle Millam
Grid card example tweaks (#29409)
Riane Milward
.eslintrc.json: Remove a couple of default rules.
Crystie Mingaud
GH Actions updates. (#29429)
Lorry Mion
Use Hugo for our docs Sass and JS. (#29280)
Parke Moneypenny
examples: darken gray a little bit.
Brinn Moses
card.md: use `text-dark` for warning card.
Elston Muffett
badge.md: use `text-dark` for warning.
Avivah Mugleston
Darken footer color.
N
Linnet Newborn
Tweak syntax highlighting colors to be WCAG2AA valid.
Andros Newcome
workflows/test.yml: switch to `setup-node@v1`. (#29410)
Juanita Nobles
Fix incorrect aspect ratio on IE11
Jaymee Noni
Remove redundant properties
O
Roseline OIlier
Responsive sticky top (#29158)
Parker Oaten
Update devDependencies. (#29381)
P
Johannes Paternoster
Typo fix (#29382)
Stephie Petrolli
Remove unnecessary z-index
EP
Egan Poetz
Make sure the content doesn't cover the navbar dropdown
Mavra Portail
about/brand.md: Remove unused class.
Danette Pountney
Use the `$white` variable.
Desirae Prahm
Docs tweaks
Q
Gayel Quesne
Move shortcodes used only once where they are needed.
R
Clayton Rosentholer
getting-started/theming.md: throw an error if the regex doesn't succeed.
Ban Rzehor
Break a couple of long lines.
S
Madeleine Salle
homepage: remove redundant class (#29357)
Annie Scarisbrick
Update subnav to remove breadcrumb and just keep versions and search (#29368)
Yvor Sheldon
Update devDependencies. (#29349)
HS
Haskel Shelper
Tweak form validation snippet. (#29359)
Guthry Shimman
Examples: use our utilities more. (#29358)
Wilburt Siegertsz
Use the example shortcode in more places. (#29346)
Kellie Skingley
ESLint: specify `--report-unused-disable-directives` (#29350)
Sawyere Skipsea
Docs: simplify a few Hugo `range`s. (#29333)
Kathryn Skypp
Fix a few redirected links. (#29352)
Dunn Slane
Fix shortcodes/example.html class bug. (#29344)
Freedman Smith
Add responsive example
Harris Speer
Allow override default col width
Cesya Spritt
Cleanup
Emlen Stairmand
Move margins, and equal height via utility example
Mela Sydes
First pass at .row-cols classes
T
Neville Trobridge
card.md remove empty `class` placeholder argument (#29345)
Onfre Tull
carousel.md: Remove duplicate bd-example div. (#29341)
Hewie Tweddle
Merge lint scripts (#29329)
U
Flossi Uttley
Clean up line heights & add line height utilities (#29271)
V
Netti Vondrasek
docs-sidebar.html: reindent. (#29337)
W
Gerti Washington
Bord Wheatcroft
Nanni Wooler